# -*- encoding: utf-8 -*-
##############################################################################
#
# Copyright (c) 2009 Dhaval Patel (dhpatel82 at gmail.com)
#                          All Rights Reserved.
#
# WARNING: This program as such is intended to be used by professional
# programmers who take the whole responsability of assessing all potential
# consequences resulting from its eventual inadequacies and bugs
# End users who are looking for a ready-to-use solution with commercial
# garantees and support are strongly adviced to contract a Free Software
# Service Company
#
# This program is Free Software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
##############################################################################
from osv import fields, osv
class res_sim_subscription_type(osv.osv):
    _description = "Subscription Types"
    _name = 'res.sim.subscription.type'
    _columns = {
        'name': fields.char("Subscription Type", size=256, required=True),
        'code': fields.char("Code", size=64),
        'has_date_option': fields.boolean('Has date options ?'),
    }
res_sim_subscription_type()

class res_sim(osv.osv):
    _description = "Sim"
    _name = 'res.sim'
    _rec_name = 'imei'
    _columns = {
        'imei': fields.char("Sim Number", size=256, required=True),
        'number': fields.char("Phone number", size=256),
        'pin': fields.char("Pin", size=256, required=True),
        'puk': fields.char("Puk", size=256, required=True),
        'subscription_type_id':fields.many2one('res.sim.subscription.type','Subscription Type'),
        'employee_id': fields.many2one('hr.employee','Employee',ondelete='cascade', required=True),
        'subscription_start_date': fields.date("Start Date"),
        'subscription_end_date': fields.date("End Date"),
        'note': fields.text('Note'),
        'has_date_option': fields.boolean('Has date options ?'),
        'default': fields.boolean('Default'),
        'data': fields.boolean('Data'),
        'voice': fields.boolean('Voice'),
        'payment_ids': fields.one2many('res.sim.payment', 'sim_id', 'Payment History'),
    }
    _defaults = {
        'default': 0,
        'data': 1,
        'voice': 1,
    }
    _sql_constraints = [
        ('imei_uniq', 'unique(imei)', 'IMEI Code must be unique !'),
    ]
    def set_default_phone(self,cr,uid,ids,context=None):
        for sim in self.read(cr,uid,ids):
            if sim['employee_id'] :
                sim_ids = self.search(cr,uid,[('employee_id','=',sim['employee_id'][0])])
                self.pool.get('hr.employee').write(cr,uid,[sim['employee_id'][0]], {'work_phone':sim['number']})
                self.write(cr,uid,sim_ids,{'default':False})
                self.write(cr,uid,[sim['id']],{'default':True})
        return True
                
        
    def _check_dates(self, cr, uid, ids, context=None):
        for i in self.read(cr, uid, ids, ['has_date_option','subscription_start_date', 'subscription_end_date'], context=context):
            if i['has_date_option'] and i['subscription_start_date'] >= i['subscription_end_date']:
                return False
        return True

    _constraints = [(_check_dates, 'Error! Subscription start date must be lower then contract end date.', ['subscription_start_date', 'subscription_end_date'])]  
    
    def onchange_subscription_type_id(self, cr, uid, ids, subscription_type_id, context=None):
        has_date_option = False
        if subscription_type_id:
            subscription_type_obj = self.pool.get('res.sim.subscription.type')
            subscription_type = subscription_type_obj.browse(cr,uid,[subscription_type_id],context)
            if subscription_type and subscription_type[0].has_date_option == True:has_date_option = True
        return {'value': {'has_date_option': has_date_option}}
res_sim()

class res_sim_payment(osv.osv):
    _description = "Sim payment line"
    _name = 'res.sim.payment'
    _columns = {
        'payment_date': fields.date("Date", required=True),
        'payment_amount': fields.float('Amount', required=True),
        'sim_id' : fields.many2one('res.sim','Sim',ondelete='cascade', required=True),
        'note': fields.text('Note')
    }
res_sim_payment()
class hr_employee(osv.osv):
    _description = "Employee"
    _inherit = 'hr.employee'
    _columns = {
        'sim_ids': fields.one2many('res.sim', 'employee_id', 'Sims'),
    }
hr_employee()

# vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:
